import {
  Action,
  getModule,
  Module,
  Mutation,
  MutationAction,
  VuexModule
} from 'vuex-module-decorators';
import { keyBy } from 'lodash';
import { User, Measure } from '@/models';
import api from '@/services/pm-api-client';
import { logService } from '@/services/logging';

@Module({ namespaced: true, name: 'measure' })
export class MeasureStoreModule extends VuexModule {
  public measures: { [key: string]: Measure } = {};

  private log = logService.getLogger('/store-modules/measure');

  @MutationAction({ mutate: ['measures'], rawError: true })
  public async fetchAllMeasures() {
    const measures = await api.getAllMeasures();
    return { measures: keyBy(measures, 'slug') };
  }

  @Action({ commit: 'SET_MEASURE', rawError: true })
  public async fetchMeasure(slug: string) {
    return await api.getMeasure(slug);
  }

  @Mutation private SET_MEASURE(measure: Measure) {
    this.measures[measure.slug] = measure;
  }
}
